@@ -5,6 +5,7 @@ import json
 import datetime
 import subprocess
 import shutil
+import StringIO
 
 import sqlite3
 import yaml
@@ -33,8 +34,7 @@ class SqliteWrapper(object):
         con, cur = self.execute(statement, *args)
         try:
             return cur.fetchone()[0]
-        except Exception, ex:
-            print "ERROR:", type(ex), ex
+        except Exception:
             return None
 
     def get(self, statement, *args):
@@ -64,6 +64,7 @@ class Worker(object):
         self.task = None
         self.subprocess = None
         self.commands = None
+        self.output = None
 
     def _work(self):
         self.task = task = self.application.db.get("SELECT * FROM task LIMIT 1")
@@ -72,6 +73,7 @@ class Worker(object):
             branch = task["branch_name"]
             commit = task["push_commit"]
 
+            self.output = StringIO.StringIO()
             self.commands = ["git checkout .", "git checkout %s" % branch, "git pull origin %s" % branch,
                              "git checkout %s" % commit, self._get_local_commands]
 
@@ -114,7 +116,7 @@ class Worker(object):
                 command()
             else:
                 try:
-                    self.subprocess = subprocess.Popen(command, shell=True)
+                    self.subprocess = subprocess.Popen(command, shell=True, stdout=self.output, stderr=self.output)
                 except OSError, ex:
                     self._fail(ex)
                 else:
@@ -136,16 +138,19 @@ class Worker(object):
         self.commands = None
         self.application.enqueue(self._work)
 
-    def _fail(self, reason):
-        print "ERROR:", reason
+    def _get_output(self):
+        output = self.output.getvalue()
+        self.output.close()
+        return output
 
-        self.application.db.update("UPDATE push SET status = ?, completed = DATETIME('NOW') WHERE id = ?",
-                                   STATUS_FAILED, self.task["push_id"])
+    def _fail(self, reason):
+        self.application.db.update("UPDATE push SET status = ?, output = ?, completed = DATETIME('NOW') WHERE id = ?",
+                                   STATUS_FAILED, self._get_output(), self.task["push_id"])
         self._complete()
 
     def _success(self):
-        self.application.db.update("UPDATE push SET status = ?, completed = DATETIME('NOW') WHERE id = ?",
-                                   STATUS_OK, self.task["push_id"])
+        self.application.db.update("UPDATE push SET status = ?, output = ?, completed = DATETIME('NOW') WHERE id = ?",
+                                   STATUS_OK, self._get_output(), self.task["push_id"])
         self._complete()
 
 
@@ -274,7 +279,7 @@ class Handler(tornado.web.RequestHandler):
                 self.write("<tr><td>%s</td><td>%s</td><td>%s</td><td>%s</td><td>%s</td></tr>" %
                            (push["status"], push["commit"], push["author"], completed, (completed - started).seconds))
             else:
-                self.write("<tr><td>%s</td><td>%s</td><td>%s</td><td colspan=2>waitinh</td></tr>" %
+                self.write("<tr><td>%s</td><td>%s</td><td>%s</td><td colspan=2>waiting</td></tr>" %
                            (push["status"], push["commit"], push["author"]))
         self.write("</table>")
 
